@@ -3,9 +3,11 @@ Main interface for kinesis-video-signaling service type definitions.
 
 Usage::
 
-    from mypy_boto3.kinesis_video_signaling.type_defs import IceServerTypeDef
+    ```python
+    from mypy_boto3_kinesis_video_signaling.type_defs import IceServerTypeDef
 
     data: IceServerTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
@@ -29,7 +31,7 @@ IceServerTypeDef = TypedDict(
 )
 
 GetIceServerConfigResponseTypeDef = TypedDict(
-    "GetIceServerConfigResponseTypeDef", {"IceServerList": List[IceServerTypeDef]}, total=False
+    "GetIceServerConfigResponseTypeDef", {"IceServerList": List["IceServerTypeDef"]}, total=False
 )
 
 SendAlexaOfferToMasterResponseTypeDef = TypedDict(
